@@ -1,4 +1,4 @@
-# Copyright (c) 2002-2004 LOGILAB S.A. (Paris, FRANCE).
+# Copyright (c) 2003-2005 LOGILAB S.A. (Paris, FRANCE).
 # http://www.logilab.fr/ -- mailto:contact@logilab.fr
 #
 # This program is free software; you can redistribute it and/or modify it under
@@ -16,16 +16,16 @@
 """utilities methods and classes for checkers
 """
 
-__revision__ = "$Id: __init__.py,v 1.18 2005/01/04 15:28:19 syt Exp $"
+__revision__ = "$Id: __init__.py,v 1.20 2005/11/02 09:21:45 syt Exp $"
 
 import tokenize
 from os import listdir
 from os.path import dirname, join, isdir, splitext
 
-from logilab.common.astng import ASTWalker
+from logilab.astng.utils import ASTWalker
 from logilab.common.configuration import OptionsProviderMixIn
 
-from logilab.pylint.reporters import diff_string, EmptyReport
+from pylint.reporters import diff_string, EmptyReport
 
 def table_lines_from_stats(stats, old_stats, columns):
     """get values listed in <columns> from <stats> and <old_stats>,
@@ -99,11 +99,10 @@ class BaseChecker(OptionsProviderMixIn, ASTWalker):
     
     def open(self):
         """called before visiting project (i.e set of modules)"""
-        
+    
     def close(self):
         """called after visiting project (i.e set of modules)"""
 
-
 class BaseRawChecker(BaseChecker):
     """base class for raw checkers"""
     
@@ -117,10 +116,11 @@ class BaseRawChecker(BaseChecker):
         self.process_tokens(tokenize.generate_tokens(stream.readline))
     
     def process_tokens(self, tokens):
-        """should be overiden by syb classes"""
+        """should be overiden by subclasses"""
         raise NotImplementedError()
 
-PYTHON_EXTENSIONS = ('.py', '.pyc', '.pyo', '.so')
+
+PY_EXTS = ('.py', '.pyc', '.pyo', '.pyw', '.so', '.dll')
 
 def initialize(linter):
     """initialize linter with checkers in this package """
@@ -134,10 +134,10 @@ def package_load(linter, directory):
     imported = {}
     for filename in listdir(directory):
         basename, extension = splitext(filename)
-        if not imported.has_key(basename) and ((
-            extension in PYTHON_EXTENSIONS and basename != '__init__') or (
-            not extension and not basename == 'CVS' and
-            isdir(join(directory, basename)))):
+        if not imported.has_key(basename) and (
+            (extension in PY_EXTS and basename != '__init__') or (
+             not extension and not basename == 'CVS' and
+             isdir(join(directory, basename)))):
             try:
                 module = __import__(basename, globs, globs, None)
             except ValueError:
