@@ -18,9 +18,9 @@
  FIXME : should check constant names !
 """
 
-__revision__ = "$Id: base.py,v 1.56 2005/05/27 09:17:14 syt Exp $"
+__revision__ = "$Id: base.py,v 1.58 2005/11/03 09:21:28 syt Exp $"
 
-from logilab.common import astng
+from logilab import astng
 from logilab.common.ureports import Table
 
 from pylint.interfaces import IASTNGChecker
@@ -55,6 +55,42 @@ def in_nested_list(nested_list, obj):
             return True
     return False
 
+def report_by_type_stats(sect, stats, old_stats):
+    """make a report of
+
+    * percentage of different types documented
+    * percentage of different types with a bad name
+    """
+    # percentage of different types documented and/or with a bad name
+    nice_stats = {} 
+    for node_type in ('module', 'class', 'method', 'function'):
+        nice_stats[node_type] = {}
+        total = stats[node_type]
+        if total == 0:
+            doc_percent = 0
+            badname_percent = 0
+        else:
+            documented = total - stats['undocumented_'+node_type]
+            doc_percent = float((documented)*100) / total
+            badname_percent = (float((stats['badname_'+node_type])*100)
+                               / total)
+        nice_stats[node_type]['percent_documented'] = doc_percent
+        nice_stats[node_type]['percent_badname'] = badname_percent
+    lines = ('type', 'number', 'old number', 'difference',
+             '%documented', '%badname')
+    for node_type in ('module', 'class', 'method', 'function'):
+        new = stats[node_type]
+        old = old_stats.get(node_type, None)
+        if old is not None:
+            diff_str = diff_string(old, new)
+        else:
+            old, diff_str = 'NC', 'NC'
+        lines += (node_type, str(new), str(old), diff_str,
+                  '%.2f' % nice_stats[node_type]['percent_documented'],
+                  '%.2f' % nice_stats[node_type]['percent_badname'])
+    sect.append(Table(children=lines, cols=6, rheaders=1))
+
+
 MSGS = {
     'E0101': ('Explicit return in __init__',
               'Used when the special class method __ini__ has an explicit \
@@ -199,14 +235,12 @@ functions, methods
                           'used, separated by a comma'}
                 ),
                )
-
+    reports = ( ('R0101', 'Statistics by type', report_by_type_stats), )
+    
     def __init__(self, linter):
         BaseChecker.__init__(self, linter)
         self.stats = None
         self._returns = None
-        self.reports = (('R0101', 'Statistics by type',
-                         self.report_by_type_stats),
-                        )
         
     def open(self):
         """initialize visit variables and statistics
@@ -262,13 +296,13 @@ functions, methods
             self._recursive_check_names(args, node)
         # check local variable, avoiding argument, imported names, global names
         # and current class name if the function is actually a method
-        for var, stmt in node.locals.items():
+        for var, stmt in node.items():
             if (not in_nested_list(args or (), var)
                 and not isinstance(stmt, astng.Import) 
                 and not isinstance(stmt, astng.From) 
                 and not isinstance(stmt, astng.Global) 
                 and not isinstance(stmt, astng.Class) 
-                and not (is_method and var == node.parent.get_frame().name)):
+                and not (is_method and var == node.parent.frame().name)):
                 self._check_name('variable', var, stmt)
         # check for redefinition
         self._check_redefinition(is_method and 'method' or 'function', node)
@@ -277,7 +311,8 @@ functions, methods
         """most of the work is done here on close:
         checks for max returns, branch, return in __init__
         """
-        if node.is_method() and node.name == '__init__' and self._returns.pop():
+        nb_returns = self._returns.pop()
+        if node.is_method() and node.name == '__init__' and nb_returns:
             self.add_message('E0101', node=node)
 
     def visit_return(self, node):
@@ -329,8 +364,8 @@ functions, methods
             name = node.node.name
             # ignore the name if it's not a builtin (ie not defined in the
             # locals nor globals scope)
-            if not (node.get_frame().locals.has_key(name) or
-                    node.root().locals.has_key(name)):
+            if not (node.frame().has_key(name) or
+                    node.root().has_key(name)):
                 if name in self.config.bad_functions:
                     self.add_message('W0141', node=node, args=name)
         if node.star_args or node.dstar_args:
@@ -355,7 +390,7 @@ functions, methods
         
     def _check_redefinition(self, redef_type, node):
         """check for redefinition of a function / method / class name"""
-        defined_self = node.parent.get_frame().locals[node.name]
+        defined_self = node.parent.frame()[node.name]
         if defined_self is not node and not are_exclusive(node, defined_self):
             self.add_message('E0102', node=node,
                              args=(redef_type, defined_self.lineno))
@@ -413,57 +448,10 @@ functions, methods
         
     def _check_required_attributes(self, node, attributes):
         """check for required attributes"""
-        locs = node.locals
         for attr in attributes:
-            if not locs.has_key(attr):
+            if not node.has_key(attr):
                 self.add_message('W0103', node=node, args=attr)
 
-    def report_by_type_stats(self, sect, stats, old_stats):
-        """make a report of
-    
-        * percentage of different types documented
-        * percentage of different types with a bad name
-        """
-        # percentage of different types documented and/or with a bad name
-        nice_stats = {} 
-        for node_type in ('module', 'class', 'method', 'function'):
-            nice_stats[node_type] = {}
-            total = stats[node_type]
-            if total == 0:
-                doc_percent = 0
-                badname_percent = 0
-            else:
-                documented = total - stats['undocumented_'+node_type]
-                doc_percent = float((documented)*100) / total
-                badname_percent = (float((stats['badname_'+node_type])*100)
-                                   / total)
-            nice_stats[node_type]['percent_documented'] = doc_percent
-            nice_stats[node_type]['percent_badname'] = badname_percent
-        
-##         for node_type in ('constant', ):#'variable', 'argument'):
-##             nice_stats[node_type] = {}
-##             total = stats[node_type]
-##             if total == 0:
-##                 badname_percent = 0
-##             else:
-##                 badname = stats['badname_'+node_type]
-##                 badname_percent = float((badname)*100) / total
-##             nice_stats[node_type]['percent_badname'] = badname_percent
-        lines = ('type', 'number', 'old number', 'difference',
-                 '%documented', '%badname')
-        for node_type in ('module', 'class', 'method', 'function'):
-            new = stats[node_type]
-            old = old_stats.get(node_type, None)
-            if old is not None:
-                diff_str = diff_string(old, new)
-            else:
-                old, diff_str = 'NC', 'NC'
-            lines += (node_type, str(new), str(old), diff_str,
-                      '%.2f' % nice_stats[node_type]['percent_documented'],
-                      '%.2f' % nice_stats[node_type]['percent_badname'])
-
-        sect.append(Table(children=lines, cols=6, rheaders=1))
-
     
 def register(linter):
     """required method to auto register this checker"""
