@@ -1,3 +1,6 @@
+# Copyright (c) 2003-2005 LOGILAB S.A. (Paris, FRANCE).
+# http://www.logilab.fr/ -- mailto:contact@logilab.fr
+#
 # This program is free software; you can redistribute it and/or modify it under
 # the terms of the GNU General Public License as published by the Free Software
 # Foundation; either version 2 of the License, or (at your option) any later
@@ -10,21 +13,16 @@
 # You should have received a copy of the GNU General Public License along with
 # this program; if not, write to the Free Software Foundation, Inc.,
 # 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
-""" Copyright (c) 2003-2005 LOGILAB S.A. (Paris, FRANCE).
- http://www.logilab.fr/ -- mailto:contact@logilab.fr
-
- basic checker for Python code
+"""classes checker for Python code
 """
 from __future__ import generators
 
-__revision__ = "$Id: classes.py,v 1.61 2005/05/27 09:19:51 syt Exp $"
+__revision__ = "$Id: classes.py,v 1.63 2005/11/02 09:21:46 syt Exp $"
 
-from logilab.common import astng
+from logilab import astng
 
 from pylint.interfaces import IASTNGChecker
 from pylint.checkers import BaseChecker
-from pylint.checkers.utils import is_abstract, is_interface, \
-     is_exception, is_metaclass, get_nodes_from_class
 
 
 MSGS = {
@@ -38,13 +36,16 @@ MSGS = {
               if you don\'t make sense of it.'),
     'F0203': ('Unable to resolve %s',
               'Used when PyLint has been unable to resolve a name.'),
+    'F0204': ('Name %s has not been resolved to a class as expected',
+              'Used when PyLint try to resolve an ancestor class name but \
+              gets something else than a Class node.'),
 
     'E0201': ('Access to undefined member %r',
               'Used when an instance member not defined in the instance, its\
               class or its ancestors is accessed.'),
-    'E0202': ('Method hide an inherited attribute from %s',
-              'Used when a class defines a method which hide an attribute from \
-              an ancestor class.'),
+    'E0202': ('An attribute inherited from %s hide this method',
+              'Used when a class defines a method which is hiden by an \
+              instance attribute from an ancestor class.'),
     'E0203': ('Access to member %r before its definition line %s',
               'Used when an instance member is accessed before it\'s actually\
               assigned.'),
@@ -59,15 +60,19 @@ MSGS = {
               'Used when a class method has an attribute different than "cls"\
               as first argument, to easily differentiate them from regular \
               instance methods.'),
-    'E0213': ('Method doesn\'t have "self" as first argument',
+    'E0213': ('Method should have "self" as first argument',
               'Used when a method has an attribute different the "self" as\
               first argument.'),
-    'E0214': ('Metaclass method doesn\'t have "mcs" as first argument',
+    'E0214': ('Metaclass method should have "mcs" as first argument',
               'Used when a metaclass method has an attribute different the \
               "mcs" as first argument.'),
     'W0211': ('Static method with %r as first argument',
               'Used when a static method has "self" or "cls" as first argument.'
               ),
+    'W0212': ('Method could be a function',
+              'Used when a method doesn\'t use its bound instance, and so could\
+              be written as a function.'
+              ),
     
     'E0221': ('Interface %s is not a class (%s)',
               'Used when a class claims to implement an interface which is not \
@@ -134,29 +139,54 @@ class ClassChecker(BaseChecker):
 separated by a comma. This is used for instance to not check methods defines \
 in Zope\'s Interface base class.'}
                 ),
+               
                ('ignore-mixin-members',
-                {'default' : 1, 'type' : 'yn', 'metavar': '<y_or_n>',
+                {'default' : True, 'type' : 'yn', 'metavar': '<y_or_n>',
                  'help' : 'Tells wether missing members accessed in mixin \
 class should be ignored. A mixin class is detected if its name ends with \
 "mixin" (case insensitive).'}
                 ),
+               
+               ('defining-attr-methods',
+                {'default' : ('__init__', '__new__', 'setUp'),
+                 'type' : 'csv',
+                 'metavar' : '<method names>',
+                 'help' : 'List of method names used to declare (i.e. assign) \
+instance attributes.'}
+                ),
+
+               ('zope',
+                {'default' : False, 'type' : 'yn', 'metavar': '<y_or_n>',
+                 'help' : 'When zope mode is activated, consider the \
+acquired-members option to ignore access to some undefined attributes.'}
+                ),
+               ('acquired-members',
+                {'default' : (
+        'REQUEST', 'acl_users', 'aq_parent'),
+                 'type' : 'csv',
+                 'metavar' : '<members names>',
+                 'help' : 'List of members which are usually get through \
+zope\'s acquisition mecanism and so shouldn\'t trigger E0201 when accessed \
+(need zope=yes to be considered.'}
+                ),
                )
 
     def __init__(self, linter=None):
         BaseChecker.__init__(self, linter)
         self._accessed = []
         self._first_attrs = []
+        self._meth_could_be_func = None
         
     def visit_class(self, node):
         """init visit variable _accessed and check interfaces
         """        
         self._accessed.append({})
-        node.metaclass = is_metaclass(node)
         self._check_bases_classes(node)
         self._check_interfaces(node)
-        if not (is_interface(node) or is_exception(node) or node.metaclass):
+        # if not an interface, exception, metaclass
+        if node.type == 'class':
             try:
-                node.get_method('__init__')
+                node.local_attr('__init__')
             except astng.NotFoundError:
                 self.add_message('W0232', args=node, node=node)
             
@@ -165,113 +195,139 @@ class should be ignored. A mixin class is detected if its name ends with \
         check that instance attributes are defined in __init__ and check
         access to existant members
         """
-        # checks attributes are defined in __init__
+        # checks attributes are defined in an allowed method such as __init__
+        defining_methods = self.config.defining_attr_methods
         for attr, node in cnode.instance_attrs.items():
-            frame = node.get_frame()
-            if frame.name not in ('__init__', '__new__', 'setUp'):
-                try:
-                    par_node = cnode.get_ancestor_for_attribute(attr)
-                    frame = par_node.instance_attrs[attr].get_frame()
-                    if frame.name not in ('__init__', '__new__',
-                                          'setUp'):
+            frame = node.frame()
+            if frame.name not in defining_methods:
+                # check attribute is defined in a parent's __init__
+                for parent in cnode.instance_attr_ancestors(attr):
+                    frame = parent.instance_attrs[attr].frame()
+                    if frame.name in defining_methods:
+                        # we're done :)
+                        break
+                else:
+                    # check attribute is defined as a class attribute
+                    try:
+                        cnode.local_attr(attr)
+                    except astng.NotFoundError:
                         self.add_message('W0201', args=attr, node=node)
-                except astng.NotFoundError:
-                    if not attr in cnode.locals:
-                        try:
-                            cnode.get_ancestor_for_class_attribute(attr)
-                        except astng.NotFoundError:
-                            self.add_message('W0201', args=attr, node=node)
         # check access to existant members on non metaclass classes
         accessed = self._accessed.pop()
-        if not cnode.metaclass and (not self.config.ignore_mixin_members or 
-                                    cnode.name[-5:].lower() != 'mixin'):
+        if cnode.type != 'metaclass' and (
+            not self.config.ignore_mixin_members
+            or cnode.name[-5:].lower() != 'mixin'):
             self._check_accessed_members(cnode, accessed)
             
     def visit_function(self, node):
         """check method arguments, overriding"""
-        # check first argument is self if this is actually a method
-        if node.is_method():
-            klass = node.parent.get_frame()
-            self._check_first_arg_for_type(node, klass.metaclass)
-            if node.name == '__init__':
-                self._check_init(node)
-                return
-            # check signature if the method overrload an herited method
+        # ignore actual functions
+        if not node.is_method():
+            return
+        self._meth_could_be_func = True
+        # check first argument is self if this is actually a method 
+        klass = node.parent.frame()
+        self._check_first_arg_for_type(node, klass.type == 'metaclass')
+        if node.name == '__init__':
+            self._check_init(node)
+            return
+        # check signature if the method overrload an herited method
+        for overriden in klass.local_attr_ancestors(node.name):
+            # get astng for the searched method
             try:
-                overriden = klass.get_ancestor_for_method(node.name)
-            except (astng.NotFoundError, astng.ASTNGBuildingException):
-                pass
-            else:
-                # get astng for the searched method
-                try:
-                    meth_node = overriden.locals[node.name]
-                    self._check_signature(node, meth_node, 'overriden')
-                except KeyError:
-                    # we have found the method but it's not in the local
-                    # dictionnary.
-                    # This may happen with astng build from living objects only
-                    pass
-            # check if the method overload an attribute
-            try:
-                overriden = klass.get_ancestor_for_attribute(node.name)
-                self.add_message('E0202', args=overriden.name, node=node)
-            except astng.NotFoundError:
-                pass
+                meth_node = overriden[node.name]
+            except KeyError:
+                # we have found the method but it's not in the local
+                # dictionnary.
+                # This may happen with astng build from living objects
+                continue
+            if not isinstance(meth_node, astng.Function):
+                continue
+            self._check_signature(node, meth_node, 'overriden')
+            break
+        # check if the method overload an attribute
+        try:
+            overriden = klass.instance_attr(node.name)
+            while not isinstance(overriden, astng.Class):
+                overriden = overriden.parent.frame()
+            self.add_message('E0202', args=overriden.name, node=node)
+        except astng.NotFoundError:
+            pass
                 
     def leave_function(self, node):
         """check method arguments, overriding"""
         # check first argument is self if this is actually a method
-        if node.is_method() and node.argnames is not None:
-            self._first_attrs.pop()
-
+        if node.is_method():
+            if node.argnames is not None:
+                self._first_attrs.pop()
+            # ignore class, static and abstract methods, initializer, and any
+            # kind of method defined in an interface for this warning
+            if (self._meth_could_be_func and node.type == 'method'
+                and node.name != '__init__'
+                and not node.is_abstract()
+                and node.parent.frame().type != 'interface'):
+                self.add_message('W0212', node=node)
+                
     def visit_getattr(self, node):
         """check if the name handle an access to a class member
         if so, register it
         """
-        if self._first_attrs and isinstance(node.expr, astng.Name):
-            if node.expr.name == self._first_attrs[-1]:
-                self._accessed[-1].setdefault(node.attrname, []).append(node)
-
+        if self._first_attrs and isinstance(node.expr, astng.Name) and \
+               node.expr.name == self._first_attrs[-1]:                
+            self._accessed[-1].setdefault(node.attrname, []).append(node)
+                
+    def visit_name(self, node):
+        """check if the name handle an access to a class member
+        if so, register it
+        """
+        if self._first_attrs and node.name == self._first_attrs[-1]:                
+            self._meth_could_be_func = False
                 
     def _check_accessed_members(self, node, accessed):
         """check that accessed members are defined"""
         for attr, nodes in accessed.items():
-            # is it a builtin attribute
+            # is it a builtin attribute ?
             if attr in ('__dict__', '__class__', '__doc__'):
+                # FIXME: old class object doesn't have __class__
+                continue
+            # is it a class attribute ?
+            try:
+                node.local_attr(attr)
+                # yes, stop here
+                continue
+            except astng.NotFoundError:
+                pass
+            # is it an instance attribute of a parent class ?
+            try:
+                node.instance_attr_ancestors(attr).next()
+                # yes, stop here
+                continue
+            except StopIteration:
+                pass
+            # if we are running in zope mode, is it an acquired attribute ?
+            if self.config.zope and attr in self.config.acquired_members:
                 continue
             # is it an instance attribute ?
-            if node.instance_attrs.has_key(attr) and not attr in node.locals:
-                try:
-                    node.get_ancestor_for_attribute(attr)
-                    # an ancestor is defining this attribute, skip it
-                except astng.NotFoundError:
-                    frame = node.instance_attrs[attr].get_frame()
-                    lineno = node.instance_attrs[attr].source_line()
-                    # check that if the node is accessed in the same method as
-                    # it's defined, it's accessed after the initial assigment
-                    for _node in nodes:
-                        if _node.get_frame() is frame and _node.lineno < lineno:
-                            self.add_message('E0203', node=_node,
-                                             args=(attr, lineno))
-                continue
-            # or a class attribute ?
-            if node.locals.has_key(attr):
-                continue
-            # or an inherited method / attribute ?
             try:
-                node.get_ancestor_for_method(attr)
+                def_node = node.instance_attr(attr)
+                instance_attribute = True
             except astng.NotFoundError:
-                pass
+                instance_attribute = False
             else:
-                continue
-            try:
-                node.get_ancestor_for_attribute(attr)
-            except astng.NotFoundError:
-                pass
-            else:
-                continue
+                # check that if the node is accessed in the same method as
+                # it's defined, it's accessed after the initial assigment
+                frame = def_node.frame()
+                lno = def_node.source_line()
+                for _node in nodes:
+                    if _node.frame() is frame and _node.lineno < lno:
+                        self.add_message('E0203', node=_node, args=(attr, lno))
             for _node in nodes:
-                self.add_message('E0201', node=_node, args=attr)
+                frame = _node.frame()
+                if frame.type == 'classmethod':
+                    if attr != '__name__':
+                        self.add_message('E0201', node=_node, args=attr)
+                elif not instance_attribute:
+                    self.add_message('E0201', node=_node, args=attr)
         
     def _check_first_arg_for_type(self, node, metaclass=0):
         """check the name of first argument, expect:
@@ -290,7 +346,7 @@ class should be ignored. A mixin class is detected if its name ends with \
             if self._first_attrs[-1] != 'mcs':
                 self.add_message('E0214', node=node)
         # static method
-        elif node.is_static_method():
+        elif node.type == 'staticmethod':
             if node.argnames and node.argnames[0] in ('self', 'cls', 'mcs'):
                 self.add_message('W0211', args=node.argnames[0], node=node)
             self._first_attrs[-1] = None
@@ -298,7 +354,7 @@ class should be ignored. A mixin class is detected if its name ends with \
         elif not node.argnames:
             self.add_message('E0211', node=node)
         # class method
-        elif node.is_class_method():
+        elif node.type == 'classmethod':
             if self._first_attrs[-1] != 'cls':
                 self.add_message('E0212', node=node)
         # regular method without self as argument
@@ -310,11 +366,11 @@ class should be ignored. A mixin class is detected if its name ends with \
         base classes
         """
         for method in node.methods():
-            owner = method.parent.get_frame()
+            owner = method.parent.frame()
             if owner is node:
                 continue
             # check that the ancestor's method is not abstract
-            if is_abstract(method, pass_is_abstract=0):
+            if method.is_abstract(pass_is_abstract=0):
                 self.add_message('W0223', node=node,
                                  args=(method.name, owner.name))
                     
@@ -322,10 +378,10 @@ class should be ignored. A mixin class is detected if its name ends with \
         """check that the given class node really implements declared
         interfaces
         """
-        def iface_handler(klass, iface_node):
+        def iface_handler(iface_node):
             """filter interface objects, it should be classes"""
             try:
-                obj = klass.resolve_dotted(iface_node.as_string())
+                obj = iface_node.resolve_dotted(iface_node.as_string())
                 if not isinstance(obj, astng.Class):
                     self.add_message('E0221', node=node,
                                      args=(iface_node.as_string(),
@@ -336,26 +392,23 @@ class should be ignored. A mixin class is detected if its name ends with \
                 self.add_message('F0203', node=node,
                                  args=(iface_node.as_string()))
                 
-        implements = astng.utils.get_interfaces(node, handler_func=iface_handler)
-        for iface in implements:
+        ignore_iface_methods = self.config.ignore_iface_methods
+        for iface in node.interfaces(handler_func=iface_handler):
             for imethod in iface.methods():
                 name = imethod.name
-                if name.startswith('_') or \
-                       name in self.config.ignore_iface_methods:
+                if name.startswith('_') or name in ignore_iface_methods:
                     # don't check method begining with an underscore, usually
                     # belonging to the interface implementation
                     continue
                 # get class method astng
                 try:
-                    method = self._get_method(node, name)
+                    method = node_method(node, name)
                 except astng.NotFoundError:
                     self.add_message('E0222', args=(name, iface.name),
                                      node=node)
                     continue
-                if method is None:
-                    continue
-                # don't go further if it is an inherited method
-                if not method.parent.get_frame() is node:
+                # ignore inherited methods
+                if method.parent.frame() is not node:
                     continue
                 # check signature
                 self._check_signature(method, imethod,
@@ -365,9 +418,9 @@ class should be ignored. A mixin class is detected if its name ends with \
         """check that the __init__ method call super or ancestors'__init__
         method
         """
-        klass_node = node.parent.get_frame()        
+        klass_node = node.parent.frame()        
         to_call, unresolved = self._ancestors_to_call(node, klass_node)
-        for stmt in get_nodes_from_class(node, astng.CallFunc):
+        for stmt in node.nodes_of_class(astng.CallFunc):
             expr = stmt.node
             if not (isinstance(expr, astng.Name) or
                     isinstance(expr, astng.Getattr)):
@@ -385,6 +438,8 @@ class should be ignored. A mixin class is detected if its name ends with \
                         return
                     self.add_message('W0233', node=expr, args=klass_name)
         for klass_name in to_call.keys():
+            if klass_name == 'object':
+                continue
             self.add_message('W0231', args=klass_name, node=node)
 
     def _check_signature(self, method1, method2, class_type):
@@ -403,18 +458,7 @@ class should be ignored. A mixin class is detected if its name ends with \
             self.add_message('W0221', args=class_type, node=method1)
         elif len(method1.defaults) != len(method2.defaults):
             self.add_message('W0222', args=class_type, node=method1)
-            
-    def _get_method(self, node, method_name, fatal=1):
-        """get astng for <method_name> on the given class node"""
-        try:
-            return node.get_method(method_name)
-        except astng.NotFoundError:
-            raise
-        except Exception:
-            if fatal:
-                self.add_message('F0201', args=(method_name, node.name),
-                                 node=node)
-            
+                        
     def _ancestors_to_call(self, node, klass_node, method='__init__'):
         """return two dictionarys :
         
@@ -446,12 +490,23 @@ class should be ignored. A mixin class is detected if its name ends with \
                     break
             else:
                 try:
-                    baseastng.get_method(method)
+                    baseastng.local_attr(method)
                     to_call[base] = 1
+                except AttributeError:
+                    self.add_message('F0204', node=baseastng, args=base)
                 except astng.NotFoundError:
                     continue
         return to_call, unresolved
         
+
+def node_method(node, method_name):
+    """get astng for <method_name> on the given class node, ensuring it
+    is a Function node
+    """
+    stmt = node.local_attr(method_name)
+    if not isinstance(stmt, astng.Function):
+        raise astng.NotFoundError(method_name)
+    return stmt
         
 def register(linter):
     """required method to auto register this checker """
