@@ -16,12 +16,12 @@
 exceptions checkers for Python code
 """
 
-__revision__ = '$Id: exceptions.py,v 1.18 2005/04/15 10:40:10 syt Exp $'
+__revision__ = '$Id: exceptions.py,v 1.19 2005/11/02 09:21:46 syt Exp $'
 
-from logilab.common import astng
+from logilab import astng
 
 from pylint.checkers import BaseChecker
-from pylint.checkers.utils import is_empty, get_names
+from pylint.checkers.utils import is_empty
 from pylint.interfaces import IASTNGChecker
 
 MSGS = {
@@ -74,7 +74,7 @@ class ExceptionsChecker(BaseChecker):
         if isinstance(node.expr1, (astng.Const, astng.Mod)):
             self.add_message('W0701', node=node)
         else:
-            name = get_names(node.expr1)[0]
+            name = node.expr1.names()[0]
             try:
                 value = node.resolve(name)
             except astng.ResolveError:
@@ -88,12 +88,12 @@ class ExceptionsChecker(BaseChecker):
                         # since None, True and False are represented by Name
                         # nodes in the ast, and so this const node doesn't
                         # have the necessary parent, lineno and so on attributes
-                        frame = node.get_frame()
+                        frame = node.frame()
                         try:
-                            lineno = frame.locals[name].source_line()
+                            lineno = frame[name].source_line()
                         except KeyError:
                             root = frame.root()
-                            lineno = root.globals[name].source_line()
+                            lineno = root[name].source_line()
                     else:
                         lineno = value.source_line()
                     self.add_message('W0706', node=node, args=(
