@@ -10,7 +10,7 @@
 # You should have received a copy of the GNU General Public License along with
 # this program; if not, write to the Free Software Foundation, Inc.,
 # 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
-""" Copyright (c) 2000-2003 LOGILAB S.A. (Paris, FRANCE).
+""" Copyright (c) 2003-2005 LOGILAB S.A. (Paris, FRANCE).
  http://www.logilab.fr/ -- mailto:contact@logilab.fr
 
 Python code format's checker.
@@ -22,9 +22,8 @@ http://www.python.org/doc/essays/styleguide.html
 Some parts of the process_token method is based from The Tab Nanny std module.
 """
 
-__revision__ = "$Id: format.py,v 1.48 2005/04/15 10:40:11 syt Exp $"
+__revision__ = "$Id: format.py,v 1.49 2005/11/02 09:21:46 syt Exp $"
 
-from os import linesep
 import re
 import tokenize
 if not hasattr(tokenize, 'NL'):
@@ -62,8 +61,8 @@ MSGS = {
     'C0324': ('Comma not followed by a space\n%s',
               'Used when a comma (",") is not followed by a space.'),
     
-    'W0331': ('Use the <> operator',
-              'Used when the <> operator is used instead of !=.'),
+    'W0331': ('Use of the <> operator',
+              'Used when the deprecated "<>" operator is used instead of "!=".'),
     'W0332': ('Use l as long integer identifier',
               'Used when a lower case "l" is used to mark a long integer. You \
 should use a upper case "L" since the letter "l" looks too much like the digit \
@@ -80,7 +79,6 @@ SASTRING_RGX = r"'([^'\\]|\\.)*('|\\$)"
 TASTRING_RGX = r"'''([^']|'(?!''))*('''|$)"
 
 # finally, the string regular expression
-STRING_RGX = re.compile('%s|%s' % (SQSTRING_RGX, SASTRING_RGX))
 STRING_RGX = re.compile('%s|%s|%s|%s' % (TQSTRING_RGX, TASTRING_RGX,
                                          SQSTRING_RGX, SASTRING_RGX))
 
@@ -143,9 +141,7 @@ def check_line(line, writer):
             string_positions = get_string_coords(line)
             for match in re.finditer(rgx_search, line):
                 if not in_coords(match, string_positions):
-                    if line.endswith(linesep):
-                        line = line[:-len(linesep)]
-                    return msg_id, pretty_match(match, line)
+                    return msg_id, pretty_match(match, line.rstrip())
             writer.add_message('F0321', line=line, args=line)
 
             
@@ -260,11 +256,11 @@ class FormatChecker(BaseRawChecker):
             return
         prev_sibl = node.previous_sibling()
         if prev_sibl is not None:
-            # don't use .source_line since it cause C0321 false positive !
+            # don't use .source_line since it causes C0321 false positive !
             prev_line = prev_sibl.lineno
         else:
             # itou ?
-            prev_line = node.parent.get_statement().lineno
+            prev_line = node.parent.statement().lineno
         line = node.source_line()
         if prev_line == line and self._visited_lines.get(line) != 2:
             self.add_message('C0321', node=node)
@@ -283,17 +279,14 @@ class FormatChecker(BaseRawChecker):
             # FIXME: internal error !
             pass
 
-    def check_lines(self, lines, start):
-        """check lines againt bad construction regexp
+    def check_lines(self, lines, i):
+        """check lines have less than a maximum number of characters
         """
         max_chars = self.config.max_line_length
-        index = 0
-        for line in lines.split(linesep):
-            line_size = len(line) - len(linesep)
-            if line_size > max_chars:
-                self.add_message('C0301', line=start + index,
-                                 args=(line_size, max_chars))
-            index += 1
+        for line in lines.splitlines():
+            if len(line) > max_chars:
+                self.add_message('C0301', line=i, args=(len(line), max_chars))
+            i += 1
         
     def check_indent_level(self, string, expected, line_num):
         """return the indent level of the string
