@@ -1,3 +1,6 @@
+# Copyright (c) 2003-2005 LOGILAB S.A. (Paris, FRANCE).
+# http://www.logilab.fr/ -- mailto:contact@logilab.fr
+#
 # This program is free software; you can redistribute it and/or modify it under
 # the terms of the GNU General Public License as published by the Free Software
 # Foundation; either version 2 of the License, or (at your option) any later
@@ -10,27 +13,26 @@
 # You should have received a copy of the GNU General Public License along with
 # this program; if not, write to the Free Software Foundation, Inc.,
 # 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
-""" Copyright (c) 2003-2005 LOGILAB S.A. (Paris, FRANCE).
- http://www.logilab.fr/ -- mailto:contact@logilab.fr
-
-imports checkers for Python code
+"""imports checkers for Python code
 """
 
-__revision__ = "$Id: imports.py,v 1.42 2005/04/15 10:40:11 syt Exp $"
+__revision__ = "$Id: imports.py,v 1.43 2005/11/02 09:21:47 syt Exp $"
 
-from logilab.common import get_cycles, astng
+from logilab.common import get_cycles
 from logilab.common.modutils import is_standard_module, is_relative, \
      get_module_part
 from logilab.common.ureports import VerbatimText, Paragraph
 
+from logilab import astng
+
 from pylint.interfaces import IASTNGChecker
 from pylint.checkers import BaseChecker, EmptyReport
 from pylint.checkers.utils import are_exclusive
 
-def get_first_import(context_dict, name, base):
+def get_first_import(context, name, base):
     """return the node where [base.]<name> is imported or None if not found
     """
-    for node in context_dict.values():
+    for node in context.values():
         if isinstance(node, astng.Import):
             if name in [iname[0] for iname in node.names]:
                 return node
@@ -250,7 +252,8 @@ given file (report R0402 must not be disabled)'}
             fullname = '%s.%s' % (basename, name)
             if fullname.find('.') > -1:
                 try:
-                    fullname = get_module_part(fullname)
+                    fullname = get_module_part(fullname,
+                                               context_file=node.root().file)
                 except Exception, ex:
                     self.add_message('F0401', args=(fullname, ex), node=node)
                     continue            
@@ -289,22 +292,24 @@ given file (report R0402 must not be disabled)'}
     def _check_deprecated(self, node, mod_path):
         """check if the module is deprecated"""
         for mod_name in self.config.deprecated_modules:
-            if mod_path.startswith(mod_name):
+            if mod_path.startswith(mod_name) and \
+                   (len(mod_path) == len(mod_name)
+                    or mod_path[len(mod_name)] == '.'):
                 self.add_message('W0402', node=node, args=mod_path)
     
     def _check_reimport(self, node, name, basename=None):
         """check if the import is necessary (i.e. not already done)
         """
-        locals_ = node.get_frame().locals
-        first = get_first_import(locals_, name, basename)
+        frame = node.frame()
+        first = get_first_import(frame, name, basename)
         if isinstance(first, (astng.Import, astng.From)) and first is not node \
                and not are_exclusive(first, node):
             self.add_message('W0404', node=node, args=(name, first.lineno))
         else:
-            globals_ = node.root().globals
-            if globals_ is locals_:
+            root = node.root()
+            if root is frame:
                 return
-            first = get_first_import(globals_, name, basename)
+            first = get_first_import(root, name, basename)
             if not isinstance(first, (astng.Import, astng.From)):
                 return
             if first is not node and not are_exclusive(first, node):
