@@ -18,11 +18,11 @@
 """
 from __future__ import generators
 
-__revision__ = '$Id: similar.py,v 1.11 2005/04/15 10:40:11 syt Exp $'
+__revision__ = '$Id: similar.py,v 1.12 2005/11/02 09:21:48 syt Exp $'
 
 import sys
 
-from logilab.common.compat import Set, izip, sum, enumerate
+from logilab.common.compat import set, izip, sum, enumerate
 from logilab.common.ureports import Table
 
 from pylint.interfaces import IRawChecker
@@ -58,7 +58,7 @@ class Similar:
                     couples.add( (lineset2, idx2) )
                     break
             else:
-                duplicate.append( Set([(lineset1, idx1), (lineset2, idx2)]) )
+                duplicate.append( set([(lineset1, idx1), (lineset2, idx2)]) )
         sims = []
         for num, ensembles in no_duplicates.iteritems():
             for couples in ensembles:
@@ -187,6 +187,15 @@ MSGS = {'R0801': ('Similar lines in %s files\n%s',
                   among multiple file. This usually means that the code should \
                   be refactored to avoid this duplication.')}
 
+def report_similarities(sect, stats, old_stats):
+    """make a layout with some stats about duplication"""
+    lines = ['', 'now', 'previous', 'difference']
+    lines += table_lines_from_stats(stats, old_stats,
+                                    ('nb_duplicated_lines',
+                                     'percent_duplicated_lines'))
+    sect.append(Table(children=lines, cols=4, rheaders=1, cheaders=1))
+
+
 # wrapper to get a pylint checker from the similar class
 class SimilarChecker(BaseChecker, Similar):
     """checks for similarities and duplicated code. This computation may be
@@ -209,15 +218,13 @@ class SimilarChecker(BaseChecker, Similar):
                  'help': 'Ignore comments when computing similarities.'}
                 ),
                )
-
+    # reports
+    reports = ( ('R0801', 'Duplication', report_similarities), )
+    
     def __init__(self, linter=None):
         BaseChecker.__init__(self, linter)
         Similar.__init__(self, min_lines=4, ignore_comments=True)
         self.stats = None
-        # provided reports
-        self.reports = (('R0801', 'Duplication',
-                         self.report_similarities),
-                        )
 
     def set_option(self, opt_name, value, action=None, opt_dict=None):
         """method called to set an option (registered in the options list)
@@ -254,6 +261,7 @@ class SimilarChecker(BaseChecker, Similar):
             msg = []
             for lineset, idx in couples:
                 msg.append("==%s:%s" % (lineset.name, idx))
+            msg.sort()
             for line in lineset._real_lines[idx:idx+num]:
                 msg.append(line.rstrip())
             self.add_message('R0801', args=(len(couples), '\n'.join(msg)))
@@ -261,14 +269,6 @@ class SimilarChecker(BaseChecker, Similar):
         stats['nb_duplicated_lines'] = duplicated
         stats['percent_duplicated_lines'] = total and duplicated * 100. / total
         
-    def report_similarities(self, sect, stats, old_stats):
-        """return a layout with some stats about duplication"""
-        lines = ['', 'now', 'previous', 'difference']
-        lines += table_lines_from_stats(stats, old_stats,
-                                        ('nb_duplicated_lines',
-                                         'percent_duplicated_lines'))
-        sect.append(Table(children=lines, cols=4, rheaders=1, cheaders=1))
-
 
 def register(linter):
     """required method to auto register this checker """
