@@ -18,12 +18,12 @@
    _ pylint.d (PYLINT_HOME)
 """
 
-__revision__ = "$Id: config.py,v 1.13 2005/01/20 15:12:54 syt Exp $"
+__revision__ = "$Id: config.py,v 1.14 2005/05/27 10:32:26 syt Exp $"
 
 import pickle
 import os
 import sys
-from os.path import exists, join, expanduser
+from os.path import exists, isfile, join, expanduser
 
 # pylint home is used to save old runs results ################################
 
@@ -79,11 +79,11 @@ else:
         PYLINTRC = ".pylintrc"
     else:
         PYLINTRC = os.path.join(USER_HOME, '.pylintrc')
-    if not exists(PYLINTRC):
-        if exists('/etc/pylintrc'):
-            PYLINTRC = '/etc/pylintrc'
-        else:
-            PYLINTRC = None
+if not isfile(PYLINTRC):
+    if isfile('/etc/pylintrc'):
+        PYLINTRC = '/etc/pylintrc'
+    else:
+        PYLINTRC = None
 
 ENV_HELP = '''
 The following environment variables are used :                                 
