@@ -1,5 +1,5 @@
-from logilab.pylint.interfaces import IRawChecker
-from logilab.pylint.checkers import BaseChecker
+from pylint.interfaces import IRawChecker
+from pylint.checkers import BaseChecker
 
 class MyRawChecker(BaseChecker):
     """check for line continuations with '\' instead of using triple
