@@ -27,7 +27,7 @@
   Display help messages about given message identifiers and exit.
 """
 
-__revision__ = "$Id: lint.py,v 1.97 2005/05/27 09:16:35 syt Exp $"
+__revision__ = "$Id: lint.py,v 1.103 2005/11/02 17:16:50 syt Exp $"
 
 from __future__ import nested_scopes
 
@@ -42,13 +42,14 @@ from os.path import dirname, basename, splitext, exists, isdir, join, normpath
 
 from logilab.common.configuration import OptionsManagerMixIn, \
      check_yn, check_csv
-from logilab.common.astng import ASTNGManager
 from logilab.common.modutils import modpath_from_file, get_module_files, \
      file_from_modpath
 from logilab.common.interface import implements
 from logilab.common.textutils import get_csv
 from logilab.common.fileutils import norm_open
 from logilab.common.ureports import Table, Text
+from logilab.common.compat import enumerate
+from logilab.astng import ASTNGManager
 
 from pylint.utils import UnknownMessage, MessagesHandlerMixIn, \
      ReportsHandlerMixIn, MSG_TYPES, sort_checkers
@@ -150,6 +151,7 @@ should be a base name, not a path. You may set this option multiple times.'}),
                
                ('parseable',
                 {'default': 0, 'type' : 'yn', 'metavar' : '<y_or_n>',
+                 'short': 'p',
                  'group': 'Reports',
                  'help' : 'Use a parseable text output format, so your favorite\
  text editor will be able to jump to the line corresponding to a message.'}),
@@ -260,11 +262,11 @@ This is used by the global evaluation report (R0004).'}),
         BaseRawChecker.__init__(self)
         # provided reports
         self.reports = (('R0001', 'Total errors / warnings',
-                         self.report_error_warning_stats),
+                         report_error_warning_stats),
                         ('R0002', '% errors / warnings by module',
-                         self.report_error_warning_by_module_stats),
+                         report_error_warning_by_module_stats),
                         ('R0003', 'Messages',
-                         self.report_messages_stats),
+                         report_messages_stats),
                         ('R0004', 'Global evaluation',
                          self.report_evaluation),
                         )
@@ -366,8 +368,8 @@ This checker also defines the following reports:
         name.
         """
         self.reporter.include_ids = self.config.include_ids
-        if type(files_or_modules) not in (type(()), type([])):
-            files_or_modules = [files_or_modules]
+        if not isinstance(files_or_modules, (list, tuple)):
+            files_or_modules = (files_or_modules,)
         checkers = sort_checkers(self._checkers.keys())
         rev_checkers = checkers[:]
         rev_checkers.reverse()
@@ -417,8 +419,6 @@ This checker also defines the following reports:
         if modname is a package, recurse on its subpackages / submodules
         """
 ##         print 'CHECKING', filepath, modname
-##         # normalize the file path to parse the python source file
-##         filepath = splitext(filepath)[0] + '.py'
         # get the given module representation
         self.base_name = modname
         self.base_file = normpath(filepath)
@@ -480,30 +480,27 @@ This checker also defines the following reports:
 
     def check_astng_module(self, astng, checkers):
         """check a module from its astng representation, real work"""
-        # this is required to make works relative imports in analyzed code
-        sys.path.insert(0, dirname(astng.file))
-        try:
-            # call raw checkers if possible
-            if not astng.pure_python:
-                self.add_message('I0001', args=astng.name)
-            else:
-                #assert astng.file.endswith('.py')
-                stream = norm_open(astng.file)
-                for checker in checkers:
-                    if implements(checker, IRawChecker):
-                        stream.seek(0)
-                        checker.process_module(stream)
-            # generate events to astng checkers
-            self.astng_events(astng, [checker for checker in checkers
-                                      if implements(checker, IASTNGChecker)])
-
-        finally:
-            sys.path.pop(0)
+        # call raw checkers if possible
+        if not astng.pure_python:
+            self.add_message('I0001', args=astng.name)
+        else:
+            #assert astng.file.endswith('.py')
+            stream = norm_open(astng.file)
+            for checker in checkers:
+                if implements(checker, IRawChecker):
+                    stream.seek(0)
+                    checker.process_module(stream)
+        # generate events to astng checkers
+        self.astng_events(astng, [checker for checker in checkers
+                                  if implements(checker, IASTNGChecker)])
     
-    def astng_events(self, astng, checkers):
+    def astng_events(self, astng, checkers, _reversed_checkers=None):
         """generate event to astng checkers according to the current astng
         node and recurse on its children
         """
+        if _reversed_checkers is None:
+            _reversed_checkers = checkers[:]
+            _reversed_checkers.reverse()
         if astng.is_statement():
             self.stats['statement'] += 1
         # generate events for this node on each checkers
@@ -511,9 +508,8 @@ This checker also defines the following reports:
             checker.visit(astng)
         # recurse on children
         for child in astng.getChildNodes():
-            self.astng_events(child, checkers)
-        checkers.reverse()
-        for checker in checkers:
+            self.astng_events(child, checkers, _reversed_checkers)
+        for checker in _reversed_checkers:
             checker.leave(astng)
         
 
@@ -543,64 +539,6 @@ This checker also defines the following reports:
             
     # specific reports ########################################################
         
-    def report_error_warning_stats(self, sect, stats, old_stats):
-        """make total errors / warnings report"""
-        lines = ['type', 'number', 'previous', 'difference']
-        lines += table_lines_from_stats(stats, old_stats,
-                                        ('convention', 'refactor',
-                                         'warning', 'error'))
-        sect.append(Table(children=lines, cols=4, rheaders=1))
-    
-    def report_messages_stats(self, sect, stats, _):
-        """make messages type report"""
-        if not stats['by_msg']:
-            # don't print this report when we didn't detected any errors
-            raise EmptyReport()
-        in_order = [(value, msg_id)
-                    for msg_id, value in stats['by_msg'].items()
-                    if not msg_id.startswith('I')]
-        in_order.sort()
-        in_order.reverse()
-        lines = ('message id', 'occurences')
-        for value, msg_id in in_order:
-            lines += (msg_id, str(value))
-        sect.append(Table(children=lines, cols=2, rheaders=1))
-        
-    def report_error_warning_by_module_stats(self, sect, stats, _):
-        """make errors / warnings by modules report"""
-        if len(stats['by_module']) == 1:
-            # don't print this report when we are analysing a single module
-            raise EmptyReport()
-        by_mod = {} 
-        for m_type in ('fatal', 'error', 'warning', 'refactor', 'convention'):
-            total = stats[m_type]
-            for module in stats['by_module'].keys():
-                mod_total = stats['by_module'][module][m_type]
-                if total == 0:
-                    percent = 0
-                else:
-                    percent = float((mod_total)*100) / total
-                by_mod.setdefault(module, {})[m_type] = percent            
-        sorted_result = []
-        for module, mod_info in by_mod.items():
-            sorted_result.append((mod_info['error'],
-                                  mod_info['warning'],
-                                  mod_info['refactor'],
-                                  mod_info['convention'],
-                                  module))
-        sorted_result.sort()
-        sorted_result.reverse()
-        lines = ['module', 'error', 'warning', 'refactor', 'convention']
-        for line in sorted_result:
-            if line[0] == 0 and line[1] == 0:
-                break
-            lines.append(line[-1])
-            for val in line[:-1]:
-                lines.append('%.2f' % val)
-        if len(lines) == 5:
-            raise EmptyReport()
-        sect.append(Table(children=lines, cols=5, rheaders=1))
-
     def report_evaluation(self, sect, stats, old_stats):
         """make the global evaluation report"""
         # check with at least check 1 statements (usually 0 when there is a
@@ -622,7 +560,67 @@ This checker also defines the following reports:
                 msg = '%s\n%s' % (msg, config.get_note_message(note))
         sect.append(Text(msg))
 
-        
+# some reporting functions ####################################################
+
+def report_error_warning_stats(sect, stats, old_stats):
+    """make total errors / warnings report"""
+    lines = ['type', 'number', 'previous', 'difference']
+    lines += table_lines_from_stats(stats, old_stats,
+                                    ('convention', 'refactor',
+                                     'warning', 'error'))
+    sect.append(Table(children=lines, cols=4, rheaders=1))
+
+def report_messages_stats(sect, stats, _):
+    """make messages type report"""
+    if not stats['by_msg']:
+        # don't print this report when we didn't detected any errors
+        raise EmptyReport()
+    in_order = [(value, msg_id)
+                for msg_id, value in stats['by_msg'].items()
+                if not msg_id.startswith('I')]
+    in_order.sort()
+    in_order.reverse()
+    lines = ('message id', 'occurences')
+    for value, msg_id in in_order:
+        lines += (msg_id, str(value))
+    sect.append(Table(children=lines, cols=2, rheaders=1))
+
+def report_error_warning_by_module_stats(sect, stats, _):
+    """make errors / warnings by modules report"""
+    if len(stats['by_module']) == 1:
+        # don't print this report when we are analysing a single module
+        raise EmptyReport()
+    by_mod = {} 
+    for m_type in ('fatal', 'error', 'warning', 'refactor', 'convention'):
+        total = stats[m_type]
+        for module in stats['by_module'].keys():
+            mod_total = stats['by_module'][module][m_type]
+            if total == 0:
+                percent = 0
+            else:
+                percent = float((mod_total)*100) / total
+            by_mod.setdefault(module, {})[m_type] = percent            
+    sorted_result = []
+    for module, mod_info in by_mod.items():
+        sorted_result.append((mod_info['error'],
+                              mod_info['warning'],
+                              mod_info['refactor'],
+                              mod_info['convention'],
+                              module))
+    sorted_result.sort()
+    sorted_result.reverse()
+    lines = ['module', 'error', 'warning', 'refactor', 'convention']
+    for line in sorted_result:
+        if line[0] == 0 and line[1] == 0:
+            break
+        lines.append(line[-1])
+        for val in line[:-1]:
+            lines.append('%.2f' % val)
+    if len(lines) == 5:
+        raise EmptyReport()
+    sect.append(Table(children=lines, cols=5, rheaders=1))
+
+
 
 # utilities ###################################################################
 
@@ -642,21 +640,21 @@ class Run:
     
     def __init__(self, args, reporter=None, quiet=0):
         rcfile = None
-        if '--rcfile' in args:
-            rcindex = args.index('--rcfile')
-            rcfile = args[rcindex + 1]
-            del args[rcindex + 1]
-            del args[rcindex]
+        for i, arg in enumerate(args):
+            if arg.startswith('--rcfile='):
+                rcfile = arg[9:]
+                del args[i]
+                break
+            if arg == '--rcfile':
+                rcfile = args[i + 1]
+                del args[i:i+2]
+                break
         self.linter = linter = PyLinter((
             ('rcfile',
              {'action' : 'callback', 'callback' : lambda *args: 1,
               'type': 'string', 'metavar': '<file>',
               'help' : 'Specify a configuration file.'}),
 
-            ('zope',
-            {'action' : 'callback', 'callback' : self.cb_init_zope,
-             'help' : 'Initialize Zope products before starting.'}),
-            
             ('disable-all',
              {'action' : 'callback',
               'callback' : self.cb_disable_all_checkers,
@@ -686,7 +684,8 @@ them in the configuration. This option causes the program to exit'''}),
 the program to exit'''}),
             
             ('profile',
-             {'action' : 'store_true',
+             {'type' : 'yn', 'metavar' : '<y_or_n>',
+              'default': False,
               'help' : 'Profiled execution.'}),
 
             ), reporter=reporter, pylintrc=rcfile)
@@ -722,23 +721,14 @@ processing.
             prof = Profile('stones.prof')
             prof.runcall(linter.check, args)
             prof.close()
-            stats = stats.load('stones.prof')
-            stats.strip_dirs()
-            stats.sort_stats('time', 'calls')
-            stats.print_stats(30)
+            data = stats.load('stones.prof')
+            data.strip_dirs()
+            data.sort_stats('time', 'calls')
+            data.print_stats(30)
         else:
             linter.check(args)
         sys.path.pop(0)
         
-    def cb_init_zope(self, *args, **kwargs):
-        """optik callback for Zope products initialization"""
-        print >> sys.stderr, 'this option is deprecated since pylint is not \
-importing analyzed code now'
-        #import Zope
-        #if hasattr(Zope, 'startup'):
-        #    # Zope >= 2.6
-        #    Zope.startup()
-
     def cb_disable_all_checkers(self, *args, **kwargs):
         """optik callback for disabling all checkers"""
         self.linter.disable_all_checkers()
