@@ -16,13 +16,13 @@
 """functional tests using the sample configuration file, should behave exactly
 as with the default configuration
 """
-__revision__ = '$Id: func_test_sample_config.py,v 1.2 2004/03/03 09:59:53 syt Exp $'
+__revision__ = '$Id: func_test_sample_config.py,v 1.3 2005/04/15 10:40:24 syt Exp $'
 
 from func_test import *
 
-from logilab import pylint
 from os.path import join
 
+import pylint
 sample_config = join(pylint.__path__[0], 'examples', 'pylintrc')
 linter.load_file_configuration(sample_config)
 
