@@ -17,4 +17,4 @@ class Test(object):
     _meta_args = ('foo', 'bar')
 
     def __init__(self):
-        print '__init__'
+        print '__init__', self
