@@ -22,3 +22,5 @@ other += '$'
 def bad_default(var, default=unknown2):
     """function with defaut arg's value set to an unexistant name"""
     print var, default
+    print xxxx
+    print xxxx #see story #1000
