@@ -8,7 +8,7 @@ class Abcd:
         self.aarg = False 
     def abcd(self, aaa, bbbb=None):
         """hehehe"""
-        print aaa, bbbb
+        print self, aaa, bbbb
     def args(self):
         """gaarrrggll"""
         self.aarg = True
@@ -21,4 +21,4 @@ class Cdef(Abcd):
 
     def abcd(self, aaa=1, bbbb=None):
         """hehehe"""
-        print aaa, bbbb
+        print self, aaa, bbbb
