@@ -11,12 +11,12 @@ class NonRegr:
 
     def sys(self):
         """should not get sys from there..."""
-        print sys
+        print self, sys
 
     def dummy(self, truc):
         """yo"""
-        return truc
+        return self, truc
     
     def blop(self):
         """yo"""
-        print 'blip'
+        print self, 'blip'
