@@ -10,13 +10,13 @@
 # You should have received a copy of the GNU General Public License along with
 # this program; if not, write to the Free Software Foundation, Inc.,
 # 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
-""" Copyright (c) 2000-2003 LOGILAB S.A. (Paris, FRANCE).
+""" Copyright (c) 2003-2005 LOGILAB S.A. (Paris, FRANCE).
  http://www.logilab.fr/ -- mailto:contact@logilab.fr
 
 Check source code is ascii only or has an encoding declaration (PEP 263)
 """
 
-__revision__ = '$Id: test_encoding.py,v 1.5 2005/04/15 10:40:25 syt Exp $'
+__revision__ = '$Id: test_encoding.py,v 1.6 2005/11/02 09:22:04 syt Exp $'
 
 import unittest
 import sys
@@ -27,6 +27,8 @@ class TestGuessEncoding(unittest.TestCase):
     def testEmacs(self):
         e = guess_encoding('# -*- coding: UTF-8  -*-')
         self.failUnlessEqual(e, 'UTF-8')
+        e = guess_encoding('# -*- coding:UTF-8 -*-')
+        self.failUnlessEqual(e, 'UTF-8')
         e = guess_encoding('''
         ### -*- coding: ISO-8859-1  -*-
         ''')
@@ -56,18 +58,5 @@ class TestGuessEncoding(unittest.TestCase):
         e = guess_encoding(' any UTF-8 data \xef\xbb\xbf')
         self.failUnlessEqual(e, None)
         
-def suite():
-    """return the unitest suite"""
-    loader = unittest.TestLoader()
-    testsuite = loader.loadTestsFromModule(sys.modules[__name__])
-    return testsuite
-
-def Run(runner=None):
-    """run tests"""
-    testsuite = suite()
-    if runner is None:
-        runner = unittest.TextTestRunner()
-    return runner.run(testsuite)
-        
 if __name__ == '__main__':
-    Run()
+    unittest.main()
