@@ -1,3 +1,6 @@
+# Copyright (c) 2003-2005 LOGILAB S.A. (Paris, FRANCE).
+# http://www.logilab.fr/ -- mailto:contact@logilab.fr
+#
 # This program is free software; you can redistribute it and/or modify it under
 # the terms of the GNU General Public License as published by the Free Software
 # Foundation; either version 2 of the License, or (at your option) any later
@@ -10,11 +13,10 @@
 # You should have received a copy of the GNU General Public License along with
 # this program; if not, write to the Free Software Foundation, Inc.,
 # 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
-""" Copyright (c) 2003-2005 LOGILAB S.A. (Paris, FRANCE).
- http://www.logilab.fr/ -- mailto:contact@logilab.fr
+"""test the pylint.checkers.utils module
 """
 
-__revision__ = '$Id: unittest_checkers_utils.py,v 1.5 2005/04/15 16:59:51 syt Exp $'
+__revision__ = '$Id: unittest_checkers_utils.py,v 1.6 2005/11/02 09:22:07 syt Exp $'
 
 import unittest
 import sys
@@ -36,8 +38,9 @@ class UtilsTC(unittest.TestCase):
 
     def test_is_builtin(self):
         self.assertEquals(utils.is_builtin('min'), True)
-        self.assertEquals(utils.is_builtin('__path__'), True)
-        self.assertEquals(utils.is_builtin('__file__'), True)
+        self.assertEquals(utils.is_builtin('__builtins__'), True)
+        self.assertEquals(utils.is_builtin('__path__'), False)
+        self.assertEquals(utils.is_builtin('__file__'), False)
         self.assertEquals(utils.is_builtin('whatever'), False)
         self.assertEquals(utils.is_builtin('mybuiltin'), False)
 
