@@ -14,7 +14,7 @@
  http://www.logilab.fr/ -- mailto:contact@logilab.fr
 """
 
-__revision__ = '$Id: unittest_lint.py,v 1.11 2005/04/07 15:43:52 syt Exp $'
+__revision__ = '$Id: unittest_lint.py,v 1.14 2005/05/27 10:32:26 syt Exp $'
 
 import unittest
 import sys
@@ -23,10 +23,10 @@ import tempfile
 from os.path import join
 from cStringIO import StringIO
 
-from logilab.pylint.config import get_note_message
-from logilab.pylint.lint import PyLinter, Run, sort_checkers, UnknownMessage
-from logilab.pylint.utils import sort_msgs
-from logilab.pylint import checkers
+from pylint.config import get_note_message
+from pylint.lint import PyLinter, Run, sort_checkers, UnknownMessage
+from pylint.utils import sort_msgs
+from pylint import checkers
 
 class SortMessagesTC(unittest.TestCase):
     
@@ -62,7 +62,7 @@ class RunTC(unittest.TestCase):
         sys.sterr = StringIO()
         try:
             try:
-                Run(args)
+                Run(args, quiet=1)
             except SystemExit, ex:
                 self.assertEquals(ex.code, exit_code)
             else:
@@ -165,9 +165,22 @@ class PyLinterTC(unittest.TestCase):
         self.assertEquals(self.linter.is_report_enabled('R0001'), False)
         self.linter.enable_report('R0001')
         self.assertEquals(self.linter.is_report_enabled('R0001'), True)
-        
 
-from logilab.pylint import config
+    def test_set_option_1(self):
+        linter = self.linter
+        linter.set_option('disable-msg', 'W0131,W0142')
+        self.assert_(not linter.is_message_enabled('W0131'))
+        self.assert_(not linter.is_message_enabled('W0142'))
+        self.assert_(linter.is_message_enabled('W0113'))
+
+    def test_set_option_2(self):
+        linter = self.linter
+        linter.set_option('disable-msg', ('W0131', 'W0142') )
+        self.assert_(not linter.is_message_enabled('W0131'))
+        self.assert_(not linter.is_message_enabled('W0142'))
+        self.assert_(linter.is_message_enabled('W0113'))
+
+from pylint import config
 
 class ConfigTC(unittest.TestCase):
 
@@ -201,9 +214,10 @@ class ConfigTC(unittest.TestCase):
             self.assertEquals(config.PYLINTRC, None)
             os.environ['PYLINTRC'] = '.'
             reload(config)
-            self.assertEquals(config.PYLINTRC, '.')
+            self.assertEquals(config.PYLINTRC, None)
         finally:
             del os.environ['PYLINTRC']
+            reload(config)
         
 if __name__ == '__main__':
     unittest.main()
