@@ -18,11 +18,11 @@
 main pylint class
 """
 
-__revision__ = "$Id: utils.py,v 1.10 2005/04/15 10:40:07 syt Exp $"
+__revision__ = "$Id: utils.py,v 1.11 2005/11/02 09:21:43 syt Exp $"
 
 from os import linesep
 
-from logilab.common.astng import Module
+from logilab.astng import Module
 from logilab.common.textutils import normalize_text
 from logilab.common.ureports import Section
 
@@ -67,15 +67,15 @@ def sort_msgs(msg_ids):
 
 def get_module_and_frameid(node):
     """return the module name and the frame id in the module"""
-    frame = node.get_frame()
+    frame = node.frame()
     module, obj = '', []
     while frame:
         if isinstance(frame, Module):
             module = frame.name
         else:
-            obj.append(frame.name)
+            obj.append(getattr(frame, 'name', '<lambda>'))
         try:
-            frame = frame.parent.get_frame()
+            frame = frame.parent.frame()
         except AttributeError:
             frame = None
     obj.reverse()
@@ -223,7 +223,7 @@ class MessagesHandlerMixIn:
         if args:
             msg %= args
         if line is None and node is not None:
-            line = node.lineno or node.get_statement().lineno
+            line = node.lineno or node.statement().lineno
             #if not isinstance(node, Module):
             #    assert line > 0, node.__class__
         # get module and object
